@@ -5,67 +5,6 @@ import re
 import formatter
 import util
 
-from HTMLParser import HTMLParser
-from htmlentitydefs import entitydefs
-
-class JavadocHtmlParser(HTMLParser):
-    def __init__(self):
-        super(JavadocHtmlParser, self).__init__(self)
-
-        self.pending_tag = None
-        self.pending_template = None
-        self.pending_data = []
-        self.output = []
-
-    def build(self):
-        self.close()
-        return ''.join(self.output)
-
-    def handle_starttag(self, tag, attrs):
-        if self.pending_tag:
-            return
-
-        if tag == 'p':
-            self.output.append('\n\n')
-            return
-
-        attrs = dict(attrs)
-        self.pending_tag = tag
-        self.pending_data = []
-
-        if tag == 'a' and 'href' in attrs:
-            self.pending_template = '`%%s <%s>`_' % (attrs['href'],)
-        elif tag == 'b':
-            self.pending_template = '**%s**'
-        elif tag == 'i':
-            self.pending_template = '*%s*'
-        elif tag == 'tt':
-            self.pending_template = '``%s``'
-        else:
-            self.pending_tag = None
-
-    def handle_endtag(self, tag):
-        if tag == self.pending_tag:
-            self.output.append(self.pending_template % (''.join(self.pending_data)))
-            self.pending_tag = None
-
-    def handle_data(self, data):
-        if self.pending_tag:
-            self.pending_data.append(data)
-        else:
-            self.output.append(data)
-
-    def handle_entityref(self, name):
-        self.handle_data(entitydefs[name])
-
-    def handle_charref(self, name):
-        if name[0] == 'x':
-            value = int(name[1:], 16)
-        else:
-            value = int(name)
-
-        self.handle_data(unichr(value))
-
 class JavadocRestCompiler(object):
     """ Javadoc to ReST compiler. Builds ReST documentation from a Java syntax
     tree. """
