@@ -175,6 +175,11 @@ class JavaMethod(JavaObject):
         mods = formatter.output_modifiers(member.modifiers).build()
         signode += nodes.Text(mods + ' ', mods + ' ')
 
+        if  member.type_parameters:
+            type_params = formatter.output_type_params(member.type_parameters).build()
+            signode += nodes.Text(type_params, type_params)
+            signode += nodes.Text(' ', ' ')
+
         rnode = addnodes.desc_type('', '')
         rnode += self._build_type_node(member.return_type)
 
@@ -469,6 +474,10 @@ class JavaDomain(Domain):
                 del self.data['packages'][modname]
 
     def resolve_xref(self, env, fromdocname, builder, typ, target, node, contnode):
+        if target in self.data['packages']:
+            obj = self.data['packages'][target]
+            return make_refnode(builder, fromdocname, obj[0], target, contnode, target)
+
         package = node.get('java:package')
         imported = node.get('java:imported')
         type_context = node.get('java:outertype')
